<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\AccountTransaction;
use DB;
use App\Bank;
use App\AccountHead;
use App\AccountCategory;

class AccountTransactionController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $banks = Bank::all();
        $heads = AccountHead::all();
        $categories = AccountCategory::all();
        $transactions = AccountTransaction::join('account_heads','account_transactions.head_id','=','account_heads.ah_id')
                                            ->join('payment_methods','account_transactions.payment_method_id','=','payment_methods.pm_id')
                                            ->join('account_categories','account_transactions.category','=','account_categories.ac_id')
                                            ->leftJoin('banks','account_transactions.bank_id','=','banks.b_id')
                                            ->orderBy('at_id','desc');
        $category = $request->category;
        $type = $request->type;
        $bank = $request->bank_id;
        $head = $request->head_id;
        $from = $request->from;
        $to = $request->to;
        if($from && $to || $bank || $head || $category || $type){
            if($from && $to){
                $transactions = $transactions->whereBetween('date',[$from,$to]);
            }if($category){
                $transactions = $transactions->where('account_transactions.category',$category);
            }if($type){
                $transactions = $transactions->where('account_transactions.type',$type);
            }if($bank){
                $transactions = $transactions->where('account_transactions.bank_id',$bank);
            }if($head){
                $transactions = $transactions->where('account_transactions.head_id',$head);
            }
            $transactions = $transactions->get();
        }else{
            $transactions = $transactions->where('date',date('Y-m-d'))->get();
        }
        $total = $transactions->sum('amount'); 
        return view('account_transactions.index',compact('transactions','banks','heads','categories','total'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $methods = DB::table('payment_methods')->get();
        $banks = Bank::all();
        $heads = AccountHead::orderby('head','asc')->get();
        $categories = AccountCategory::all();
        return view('account_transactions.create',compact('methods','banks','heads','categories'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(count($request->head) > 0){
            for($i = 0 ; $i < count($request->head) ; $i++  ){
                $category = AccountHead::join('account_categories','account_heads.category','=','account_categories.ac_id')->find($request->head[$i]);
                $transactions = new AccountTransaction;
                $transactions->date =$request->date;
                $transactions->type = $request->type;
                $transactions->category = $category->category;
                $transactions->head_id = $request->head[$i];
                $transactions->amount = $request->amount[$i];
                $transactions->payment_method_id = $request->payment_method[$i];
                $transactions->bank_id = $request->bank[$i];
                $transactions->remarks = $request->remarks[$i];
                $transactions->save();
            }
        }
        
        return Redirect()->back()->with('success','Transcation added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $transaction = AccountTransaction::join('account_heads','account_transactions.head_id','=','account_heads.ah_id')
                                            ->join('payment_methods','account_transactions.payment_method_id','=','payment_methods.pm_id')
                                            ->join('account_categories','account_transactions.category','=','account_categories.ac_id')
                                            ->leftJoin('banks','account_transactions.bank_id','=','banks.b_id')
                                            ->find($id);
        $methods = DB::table('payment_methods')->get();
        $banks = Bank::all();
        $heads = AccountHead::all();
        $categories = AccountCategory::all();
        
        return view('account_transactions.edit',compact('transaction','methods','banks','heads','categories'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $transactions = AccountTransaction::find($id);
        $transactions->date =$request->date;
        $transactions->type = $request->type;
        $transactions->category = $request->category;
        $transactions->head_id = $request->head;
        $transactions->amount = $request->amount;
        $transactions->payment_method_id = $request->payment_method;
        $transactions->bank_id = $request->bank;
        $transactions->remarks = $request->remarks;
        $transactions->save();
        return Redirect('account_transactions')->with('success','Transcation update successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    
    function headDetails(Request $request){
        
        
        $head = AccountHead::where('category','=',$request->id)->get();
        
        return $head;
    }
    
    public function TransactionReport(Request $request){
        
        $array_debit = [];
        $array_credit = [];
        $heads = AccountHead::join('account_categories','account_heads.category','=','account_categories.ac_id')->get();
        
        $finYear = date('2022-04-01');
        $yesterday = date('Y-m-d',strtotime("-1 days"));
        $today = date('Y-m-d');
        $from = $request->from;
        $to = $request->to;
        if($from && $to ){
            $date1 = $finYear;
            $date2 = date('Y-m-d',strtotime($from ."-1 days"));
            $date3 = $from;
            $date4 = $to;
        }else{
            $date1 = $finYear;
            $date2 = $yesterday;
            $date3 = $today;
            $date4 = $today;
        }
        
        //opening balance
        $op_credit = AccountTransaction::whereBetween('date',[$date1,$date2])->where('type','=','1')->sum('amount');
        $op_debit = AccountTransaction::whereBetween('date',[$date1,$date2])->where('type','=','2')->sum('amount');
        $opening_balance = $op_credit - $op_debit;
        
        //closing balance
        $cl_credit = AccountTransaction::whereBetween('date',[$date3,$date4])->where('type','=','1')->sum('amount');
        $cl_debit = AccountTransaction::whereBetween('date',[$date3,$date4])->where('type','=','2')->sum('amount');
        $closing_balance = $opening_balance + $cl_credit - $cl_debit;
        
        $credit = 0;
        foreach($heads as $head){
            $transactions_debit = AccountTransaction::join('account_heads','account_transactions.head_id','=','account_heads.ah_id')
                                            ->join('account_categories','account_transactions.category','=','account_categories.ac_id')
                                            ->where('head_id','=',$head->ah_id)
                                            ->where('account_transactions.type','=','2');
                                            
                                            
                                         
            //seach
            if($from && $to){
                $transactions_debit = $transactions_debit->whereBetween('date',array($from,$to))->orderBy('account_transactions.type','ASC')->get();
            }else{
                $transactions_debit = $transactions_debit->where('date',date('Y-m-d'))->orderBy('account_transactions.type','ASC')->get();
            }
            
            $debit = $transactions_debit->sum('amount');
            
            //array psuh
            if(count($transactions_debit) > 0){
                $array_debit[] = [
                    'category' => $head->account_category,
                    'head' => $head->head,
                    'credit' => $credit,
                    'debit' => $debit,
                ];
            }
            
            
        }
        
        $debit = 0;
        foreach($heads as $head){
             $transactions_credit = AccountTransaction::join('account_heads','account_transactions.head_id','=','account_heads.ah_id')
                                            ->join('account_categories','account_transactions.category','=','account_categories.ac_id')
                                            ->where('head_id','=',$head->ah_id)
                                            ->where('account_transactions.type','=','1');                                
            //seach
            if($from && $to){
                $transactions_credit =$transactions_credit->whereBetween('date',array($from,$to))->orderBy('account_transactions.type','ASC')->get();
            }else{
                $transactions_credit = $transactions_credit->where('date',date('Y-m-d'))->orderBy('account_transactions.type','ASC')->get();
            }
            
            $credit =  $transactions_credit->sum('amount');
            
            //array psuh
            if(count($transactions_credit) > 0){
                $array_credit[] = [
                    'category' => $head->account_category,
                    'head' => $head->head,
                    'credit' => $credit,
                    'debit' => $debit,
                ];
            }
            
        }
        return view('account_transactions.report',compact('array_debit','array_credit','opening_balance','closing_balance'));
    }
}
