<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Bank;
use App\AccountTransaction;

class BankController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $banks = Bank::all();
        return view('bank.index',compact('banks'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view('bank.create');
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $bank = new Bank;
        $bank->bank_name = $request->bank_name;
        $bank->branch = $request->branch;
        $bank->ifsc = $request->ifsc;
        $bank->account_no = $request->account_no;
        $bank->save();
        
        return redirect()->back()->with('success','Bank added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $bank = Bank::find($id);
        return view('bank.edit',compact('bank'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $bank = Bank::find($id);
        $bank->bank_name = $request->bank_name;
        $bank->branch = $request->branch;
        $bank->ifsc = $request->ifsc;
        $bank->account_no = $request->account_no;
        $bank->save();
        
        return redirect('/banks')->with('success','Bank updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    
    
    //Bank REPORT
    public function BankReport(Request $request){
        
        
        //seach
        $from = $request->from;
        $to = $request->to;
        $bank_id = $request->bank_id;
        if($bank_id){
            $banks = Bank::where('b_id','=',$bank_id)->get();
        }else{
            $banks = Bank::all();
        }
        if($from && $to ){
            $date1 = $from;
            $date2 = $to;
        }else{
            $date1 = date('Y-m-d');
            $date2 = date('Y-m-d');
        }
        $report = [];
        
        foreach($banks as $bank){
            
            $transactions = AccountTransaction::where('bank_id','=',$bank->b_id)->whereBetween('date',[$date1,$date2])->get();
            $credit = AccountTransaction::where('bank_id','=',$bank->b_id)->where('type','=','1')->sum('amount');
            $debit = AccountTransaction::where('bank_id','=',$bank->b_id)->where('type','=','2')->sum('amount');
            $balance =  $debit - $credit;
            
            
            if(count($transactions) > 0){
                //array push
                $report[] = [
                    'bank' => $bank->bank_name,
                    'withdraw' => $transactions->where('type','=','1')->sum('amount'),
                    'deposit' => $transactions->where('type','=','2')->sum('amount'),
                    'balance' => $balance,
                ];
            }
        }
        
        return view('bank.report',compact('report','banks'));
    }
}
