<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\BillItems;
use App\Bills;
use DB;
use App\Sale;
use App\Suppliers;
use App\Tables;
use App\Units;
use App\ItemPrice;
use Auth;
use App\Counters;


class BillController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)//view Bot
    {
        $suppliers = Suppliers::all();
        $counters = Counters::where('purpose','=','1')->get();
        if(Auth::user()->role == '1' ){
            $bills = Bills::join('suppliers','bills.supplier_id','=','suppliers.s_id')
            ->join('tables','bills.table_id','=','tables.t_id')
            ->join('counters','bills.counter_id','=','counters.cntr_id')
            ->where('bills.status','!=','2')
            ->where('bills.category','=','1')
            ->orderBy('b_id','desc');
        }else{
            $bills = Bills::join('suppliers','bills.supplier_id','=','suppliers.s_id')
            ->join('tables','bills.table_id','=','tables.t_id')
            ->where('bills.counter_id','=',Auth::user()->counter_id)
            ->where('bills.status','!=','2')
            ->where('bills.category','=','1')
            ->orderBy('b_id','desc');
        }
        
        
        $from = $request->from;
        $to = $request->to;
        $supplier = $request->supplier_id;
        $counter = $request->counter_id;
        
        if($from && $to || $supplier || $counter){
            if($from && $to){
                $bills = ($bills)->whereBetween('bills.date',[$from,$to]);
            }if($supplier){
                $bills = ($bills)->where('bill_items.supplier_id',$supplier); 
            }if($counter){
                $bills = ($bills)->where('bills.counter_id',$counter); 
            }
            $bills = ($bills)->get();
        }else{
            $bills = $bills->where('bills.date',date('Y-m-d'))->get();
        }
        return view('sales.view_bot',compact('bills','suppliers','counters'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request) //KOT & BOT
    {
        
        $today = date('Y-m-d');
        if($request->ot == 1){ //bot
            $sales = BillItems::join('items','bill_items.item_id','=','items.item_id')
                    ->where('counter_id','=',$request->counter_id)
                    ->where('table_id','=',$request->table_id)
                    ->where('order_no','=',$request->order_no)
                    ->where('bill_items.status','=','0')
                    ->where('item_head_id','!=','5')
                    ->get();
        }else{//kot
            $sales = BillItems::join('items','bill_items.item_id','=','items.item_id')
                    ->where('counter_id','=',$request->counter_id)
                    ->where('table_id','=',$request->table_id)
                    ->where('order_no','=',$request->order_no)
                    ->where('bill_items.status','=','0')
                    ->where('item_head_id','=','5')
                    ->get();
        }
        
        if(count($sales)>0){
        
            $bill_no = DB::table('bill_numbers')->first();
            if($bill_no->date != $today){
                DB::table('bill_numbers')->limit(1)->update([ 'date' => $today , 'bill_no' => 1 , 'bot_no' => 1 ]);
            }
            $bill_no = DB::table('bill_numbers')->first();
            $bill = new Bills;
            $bill->date = $today;
            $bill->total_amount =  $sales->sum('amount');
            if($request->ot == 1){
                $bill->bill_no = $bill_no->bot_no;
                $bill->category = 1;
            }else{
                $bill->bill_no = $bill_no->bill_no;
                $bill->category = 0;
            }
            $bill->table_id = $request->table_id;
            $bill->order_no = $request->order_no;
            $bill->supplier_id = $request->supplier_id;
            $bill->counter_id = $request->counter_id;
            $bill->status = '0';
            $bill->save();
            
            if($request->ot == 1){
                DB::table('bill_numbers')->limit(1)->update(['bot_no' => $bill_no->bot_no + 1]);
            }else{
                DB::table('bill_numbers')->limit(1)->update(['bill_no' => $bill_no->bill_no + 1]);
            }
            
            
            
            $billno = $bill->b_id;
        
           
            foreach($sales as $sale){
            
                $bi_id = $sale->bi_id;
                $update = BillItems::find($bi_id);
                $update->status = '1';
                $update->bill_id = $billno;
                $update->save();
            }
            
            $id = $bill->b_id;
            return $this->show($id);
        }
        
        
        
       
        return Redirect()->back();
            
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $bills = Bills::join('bill_items','bills.b_id','=','bill_items.bill_id')
                        ->join('suppliers','bill_items.supplier_id','=','suppliers.s_id')
                        ->join('tables','bill_items.table_id','=','tables.t_id')
                        ->join('counters','bill_items.counter_id','=','counters.cntr_id')
                        ->find($id);
        $food_item_sum =    BillItems::join('items','bill_items.item_id','=','items.item_id')->where('items.item_head_id','=','5')->where('bill_id','=',$id)->sum('amount'); 
        $gst_amount = $food_item_sum * 5 /(100 + 5);
        $gst_amount = number_format((float)$gst_amount, 2, '.', '');
        $gst  = $gst_amount /2;
        $items = BillItems::join('items','bill_items.item_id','=','items.item_id')
                        ->join('units','bill_items.unit_id','=','units.u_id')
                        ->where('bill_id','=',$id)
                        ->get();
        return view('sales.kot',compact('bills','items','gst'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $kots = Bills::join('bill_items','bills.b_id','=','bill_items.bill_id')
                        ->join('suppliers','bill_items.supplier_id','=','suppliers.s_id')
                        ->join('tables','bill_items.table_id','=','tables.t_id')
                        ->join('counters','bill_items.counter_id','=','counters.cntr_id')
                        ->join('items','bill_items.item_id','=','items.item_id')
                        ->join('units','bill_items.unit_id','=','units.u_id')
                        ->select('*','bill_items.counter_id as counter_id')
                        ->find($id);
        $kot_items = BillItems::join('items','bill_items.item_id','=','items.item_id')->join('units','bill_items.unit_id','=','units.u_id')->where('bill_id',$id)->get();
        $suppliers = Suppliers::all();
        $tables = Tables::all();
        $units = Units::all();
        $items = ItemPrice::join('items','item_prices.item_id','=','items.item_id')->where('counter_id',$kots->counter_id)->orderBy('name','asc')->groupBy('name')->get();
        return view('sales.edit_kot',compact('kots','suppliers','tables','units','items','kot_items'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        
        
        
        $delete = BillItems::where('bill_id','=',$id)->forceDelete();
        if(count($request->item_id) >0 ){
            for($i = 0 ;$i<count($request->item_id);$i++){
                $price = ItemPrice::where('item_id',$request->item_id[$i])->where('unit_id',$request->unit_id[$i])->where('counter_id',$request->counter_id)->first(); 
                $bill = new BillItems;
                $bill->supplier_id = $request->supplier_id;
                $bill->counter_id = $request->counter_id;
                $bill->bill_id = $id;
                $bill->table_id = $request->table_id;
                $bill->item_id = $request->item_id[$i];
                $bill->qty = $request->qty[$i];
                if($price->count() > 0){
                    $bill->rate = $price->amount;
                    $bill->amount = $price->amount * $request->qty[$i];
                }else{
                    $bill->rate = 0;
                    $bill->amount = 0 * $request->qty;
                }
                $bill->status = 1;
                $bill->order_no = $request->order_no;
                $bill->unit_id = $request->unit_id[$i];
                $bill->save();
            }
        }
        $total = BillItems::where('bill_id','=',$id)->sum('amount');
        $bills = Bills::find($id);
        $bills->table_id = $request->table_id;
        $bills->order_no = $request->order_no;
        $bills->supplier_id = $request->supplier_id;
        $bills->total_amount = $total;
        $bills->save();
        if($bills->category == 0){
            return redirect()->route('sales.index')->with('success','KOT updated successfully');
        }else{
            return redirect('/bills')->with('success','BOT updated successfully');
        }
        
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    
    
    
    public function AddBills(Request $request){
        $sales = BillItems::where('counter_id','=',$request->counter_id)
                    ->where('table_id','=',$request->table_id)
                    ->where('order_no','=',$request->order_no)
                    ->where('status','=','1')
                    ->where('sale_id','=','0')
                    ->get();
        $total = BillItems::where('counter_id','=',$request->counter_id)
                    ->where('table_id','=',$request->table_id)
                    ->where('order_no','=',$request->order_no)
                    ->where('status','=','1')
                    ->where('sale_id','=','0')
                    ->sum('amount');
        // dd($sales);
        $bill_no = DB::table('sale_numbers')->first();
        $bill = new Sale;
        $bill->date = date('Y-m-d');
        $bill->amount =  $total;
        $bill->sale_no = $bill_no->sale_no;
        $bill->counter_id = $request->counter_id;
        $bill->save();
        
        DB::table('sale_numbers')->limit(1)->update(['sale_no' => $bill_no->sale_no + 1]);
        
        $billid = $bill->sale_id;
        
        if(count($sales)>0){
           
            foreach($sales as $sale){
            
            $bi_id = $sale->bi_id;
            $update = BillItems::find($bi_id);
            $update->status = '2';
            $update->sale_id = $billid;
            $update->save();
            $status = Bills::find($sale->bill_id);
            $status->status = '1';
            $status->save();
            
            
          }
        }
        $id = $bill->sale_id;
        return $this->PrintBills($id);
        
    }
    
    public function PrintBills($id){
        $bills = Sale::join('bill_items','sales.sale_id','=','bill_items.sale_id')
                        ->join('suppliers','bill_items.supplier_id','=','suppliers.s_id')
                        ->join('tables','bill_items.table_id','=','tables.t_id')
                        ->find($id);
        $food_item_sum =    BillItems::join('items','bill_items.item_id','=','items.item_id')->where('items.item_head_id','=','5')->where('sale_id','=',$id)->sum('amount');
        $gst_amount = $food_item_sum * 5 /(100 + 5);
        $gst_amount = number_format((float)$gst_amount, 2, '.', '');
        $gst  = $gst_amount /2;
        $items = BillItems::join('items','bill_items.item_id','=','items.item_id')->where('sale_id','=',$id)->get();
        return view('sales.bill',compact('bills','items','gst'));
    }
    
    
    // Cancel Kot
    public function CancelKot($id){
        
        $cancel = Bills::find($id);
        $cancel->status = '2';
        $cancel->save();
        return Redirect('bills/cancel/kot/view')->with('success','Kot cancelled successfully');
    }
    // view Canceled kot
    public function ViewCanceledKot(){
        $bills = Bills::join('suppliers','bills.supplier_id','=','suppliers.s_id')
            ->join('tables','bills.table_id','=','tables.t_id')
            ->join('counters','bills.counter_id','=','counters.cntr_id')
            ->where('bills.status','=','2')
            ->orderBy('b_id','desc')
            ->get();
        return view('sales.canceled_kot',compact('bills'));
    }
    
    
    //kot details
    public function KotDetails(Request $request){
        
        
        $details = BillItems::join('items','bill_items.item_id','=','items.item_id')
                    ->join('units','bill_items.unit_id','=','units.u_id')
                    ->where('bill_items.counter_id','=',$request->counter_id)
                    ->where('bill_items.table_id','=',$request->table_id)
                    ->where('bill_items.order_no','=',$request->order_no)
                    ->where('status','=','1')
                    ->get();
        $sum = BillItems::join('items','bill_items.item_id','=','items.item_id')
                    ->join('units','bill_items.unit_id','=','units.u_id')
                    ->where('bill_items.counter_id','=',$request->counter_id)
                    ->where('bill_items.table_id','=',$request->table_id)
                    ->where('bill_items.order_no','=',$request->order_no)
                    ->where('status','=','1')
                    ->sum('amount');
        return view('sales.kot_details',compact('details','sum'));
    }
}
