<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Item;
use App\ItemCase;
use App\Units;
use App\Counters;

class ItemCaseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $cases= ItemCase::join('items','item_cases.item_id','=','items.item_id')->join('units','item_cases.unit_id','=','units.u_id')->get();
        
        return view('item_cases.index')->with('cases',$cases);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        
        $items = Item::all();
        $units = Units::All();
        
        return view('item_cases.create')
                        ->with('items',$items)
                        ->with('units',$units);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
        for($i = 0 ; $i < count($request->item)  ; $i++ ){
            
            $item_price = new ItemCase;
            $item  =  Item::find($request->item[$i]);
            $item_price->item_id = $request->item[$i];
            $item_price->unit_id = $request->unit[$i];
            $item_price->head_id = $item->item_head_id;
            $item_price->case_count = $request->case_count[$i];
            $item_price->case_amount = $request->case_amount[$i];
            $item_price->item_amount = number_format((float)($request->case_amount[$i] / $request->case_count[$i]), 2, '.', '');
            $item_price->save();
        }
        return redirect()->back()->with('success','Item Case Added Successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $cases= ItemCase::join('items','item_cases.item_id','=','items.item_id')->join('units','item_cases.unit_id','=','units.u_id')->find($id);
        $items = Item::all();
        $units = Units::All();
        return view('item_cases.edit',compact('cases','items','units'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $item_price = ItemCase::find($id);
        $item  =  Item::find($request->item);
        $item_price->item_id = $request->item;
        $item_price->unit_id = $request->unit;
        $item_price->head_id = $item->item_head_id;
        $item_price->case_count = $request->case_count;
        $item_price->case_amount = $request->case_amount;
        $item_price->item_amount = number_format((float)($request->case_amount / $request->case_count), 2, '.', '');
        $item_price->save();
        
        return redirect("/item_cases")->with('success','Item Case Updated Successfully');;
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
