<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\ItemHeads;
use App\Item;
use App\item_units;
use App\ItemCategory;

class ItemController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        $items = Item::join('item_heads','items.item_head_id','=','item_heads.ih_id')
                        ->join('item_categories','items.category_id','=','item_categories.ic_id')
                        ->leftjoin('item_units','items.mls','=','item_units.id')
                        ->get();
      
        return view('items.index')->with('items',$items);
        
        
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $categories = ItemCategory::All();
        $units = item_units::all();
        $heads = ItemHeads::all();
        
        return view('items.create')->with('heads',$heads)->with('units',$units)->with('categories',$categories);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(count($request->item_name) >0 ){
            for($i = 0 ;$i<count($request->item_name);$i++){
                $item = new Item;
                $item->item_head_id =  $request->head;
                $item->name =  $request->item_name[$i];
                $item->code =  $request->item_code[$i];
                // $item->mls =  $request->mls[$i];
                $item->tax =  $request->taxs[$i];
                $item->hsncode =  $request->hsncodes[$i];
                $item->category_id =  $request->category_id;
                $item->save();
            }
        }
            
       
        return redirect('/items')->with('success','Item Added successfully');
        
         
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $item = Item::join('item_heads','items.item_head_id','=','item_heads.ih_id')
                        ->join('item_categories','items.category_id','=','item_categories.ic_id')
                        ->leftjoin('item_units','items.mls','=','item_units.id')
                        ->select('*','items.category_id as category_id')
                        ->find($id);
        $heads = ItemHeads::all();
        $units = item_units::all();
        $categories = ItemCategory::All();
        return view('items.edit',compact('item','heads','categories','units'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $item = Item::find($id);
        $item->item_head_id =  $request->head;
        $item->name =  $request->item_name;
        $item->code =  $request->item_code;
        // $item->mls =  $request->mls;
        $item->tax =  $request->taxs;
        $item->hsncode =  $request->hsncodes;
      
        $item->category_id =  $request->category_id;
        $item->save();
            
        return redirect('/items')->with('success','Item Updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
