<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Item;
use App\ItemPrice;
use App\Units;
use App\Counters;
use App\ItemHeads;
use App\ItemCategory;


class ItemPriceController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $prices = ItemPrice::join('items','item_prices.item_id','=','items.item_id')
                ->join('counters','item_prices.counter_id','=','counters.cntr_id')
                ->join('units','item_prices.unit_id','=','units.u_id')
                ->select('*','item_prices.amount as item_amount');
        $counters = Counters::all();
        $heads = ItemHeads::all();
        $units = Units::All();
        $categories = ItemCategory::all();
        
        $counter = $request->counter_id;
        $head = $request->item_head_id;
        $unit = $request->unit_id;
        $category = $request->category_id;
        
        if( $counter || $head || $unit || $category ){
            if($counter){
                $prices = $prices->where('counter_id','=',$counter);
            }if($head){
                $prices = $prices->where('item_head_id','=',$head);
            }if($unit){
                $prices = $prices->where('unit_id','=',$unit);
            }if($category){
                $prices = $prices->where('items.category_id','=',$category);
            }
            $prices = $prices->get();
        }else{
            $prices = $prices->get();
        }
        
        return view('item_prices.index')->with('prices',$prices)
                                        ->with('counters',$counters)
                                        ->with('heads',$heads)
                                        ->with('units',$units)
                                        ->with('categories',$categories);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $counters = Counters::all();
        $items = Item::all();
        $units = Units::All();
        
        return view('item_prices.create')->with('counters',$counters)
                        ->with('items',$items)
                        ->with('units',$units);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        if(count($request->unit)>0){
            for($i=0; $i<count($request->unit) ; $i++){
                $item_price = new ItemPrice;
                $item_price->item_id = $request->item;
                $item_price->counter_id = $request->counter;
                $item_price->unit_id = $request->unit[$i];
                $item_price->amount = $request->amount[$i];
                $item_price->save();
            }
            
        }
        
        
        return redirect()->back()->with('success','Price added successfully');
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $counters = Counters::all();
        $items = Item::all();
        $units = Units::All();
        $price = ItemPrice::join('items','item_prices.item_id','=','items.item_id')->join('counters','item_prices.counter_id','=','counters.cntr_id')->join('units','item_prices.unit_id','=','units.u_id')->find($id);
        
        return view('item_prices.edit')->with('counters',$counters)
                        ->with('items',$items)
                        ->with('units',$units)
                        ->with('price',$price);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $item_price = ItemPrice::find($id);
        $item_price->item_id = $request->item;
        $item_price->counter_id = $request->counter;
        $item_price->unit_id = $request->unit;
        $item_price->amount = $request->amount;
        $item_price->save();
        
        return redirect("/item_prices");
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
