<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\KitchenItem;
use App\Counters;
use App\KitchenIssue;
use App\KitchenIssueItem;
use DB;
use App\KitchenPurchaseUnit;
use App\KitchenPurchaseItem;

class KitchenIssueController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $issues = KitchenIssue::join('counters','kitchen_issues.counter_id','=','counters.cntr_id')->orderBy('kis_id','desc');
            
        
        $counters = Counters::where('purpose','=',2)->get();
        $from = $request->from;
        $to = $request->to;
        $counter = $request->counter_id;
        if($from && $to || $counter){
            if($from && $to ){
                $issues = $issues->whereBetween('date',array($from,$to));
            }if($counter){
                $issues = $issues->where('counter_id',$counter);
            }
            $issues = $issues->get();
        }else{
            $issues = $issues->where('date',date('Y-m-d'))->get();
        }
        return view('kitchen_issues.index',compact('issues','counters'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $items = KitchenItem::all();
        $counters = Counters::where('purpose','=',2)->get();
        $units = KitchenPurchaseUnit::all();
        $issue_no = DB::table('kitchen_issue_numbers')->first();
        return view('kitchen_issues.create',compact('items','counters','issue_no','units'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
        $issue  =  new KitchenIssue;
        $issue->issue_no = $request->issue_no;
        $issue->date = $request->date;
        $issue->counter_id = $request->counter_id;
        $issue->remarks = $request->remarks;
        $issue->save();
        DB::table('kitchen_issue_numbers')->limit(1)->update(['number' => $request->issue_no + 1]);
        if(count($request->item_id) > 0 ){
           for($i = 0 ; $i < count($request->item_id) ; $i++  ){
               $rate = KitchenPurchaseItem::where('item_id',$request->item_id[$i])->latest()->first();
               $item = new KitchenIssueItem;
               $item->issue_id = $issue->kis_id;
               $item->item_id = $request->item_id[$i];
               $item->quantity = $request->qty[$i];
               $item->unit_id = $request->unit_id[$i];
               if($rate){
                   $item->rate = $rate->rate;
                   $item->amount = $request->qty[$i] *  $rate->rate;
               }else{
                   $item->rate = 0;
                   $item->amount =  0;
               }
               $item->save();
           }
        }
        return redirect()->back()->with('success','Kitchen Issue added successfully');
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $items = KitchenIssueItem::join('kitchen_items','kitchen_issue_items.item_id','=','kitchen_items.ki_id')
                        ->join('kitchen_purchase_units','kitchen_issue_items.unit_id','=','kitchen_purchase_units.id')
                        ->where('issue_id','=',$id)->get();
        return view('kitchen_issues.view_issued_items',compact('items'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $items = KitchenItem::all();
        $counters = Counters::where('purpose','=',2)->get();
        $units = KitchenPurchaseUnit::all();
        $issues = KitchenIssue::join('counters','kitchen_issues.counter_id','=','counters.cntr_id')->find($id);
        $issue_items = KitchenIssueItem::join('kitchen_items','kitchen_issue_items.item_id','=','kitchen_items.ki_id')
                        ->join('kitchen_purchase_units','kitchen_issue_items.unit_id','=','kitchen_purchase_units.id')
                        ->where('issue_id','=',$id)->get();
        return view('kitchen_issues.edit',compact('items','counters','units','issues','issue_items'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $issue  =  KitchenIssue::find($id);
        $issue->issue_no = $request->issue_no;
        $issue->date = $request->date;
        $issue->counter_id = $request->counter_id;
        $issue->remarks = $request->remarks;
        $issue->save();
        KitchenIssueItem::where('issue_id','=',$id)->forceDelete();
        if(count($request->item_id) > 0 ){
           for($i = 0 ; $i < count($request->item_id) ; $i++  ){
               $item = new KitchenIssueItem;
               $item->issue_id = $issue->kis_id;
               $item->item_id = $request->item_id[$i];
               $item->quantity = $request->qty[$i];
               $item->unit_id = $request->unit_id[$i];
                   $item->rate = $request->rate[$i];
                   $item->amount = $request->qty[$i] *  $request->rate[$i];
               
               $item->save();
           }
        }
        return redirect('/kitchen_issues')->with('success','Kitchen Issue updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    
    public function ItemWiseReport(Request $request){
        
        $from = $request->from;
        $to = $request->to;
        $counter = $request->counter_id;
        $main_array  =  array();
        
        if($counter){
            $counters = Counters::where('cntr_id','=',$counter)->get(); 
            
        }else{
             $counters = Counters::all();
        }
        
            if(count($counters) > 0 ){
                    foreach($counters as $counter){
                         $issues = KitchenIssue::join('counters','kitchen_issues.counter_id','=','counters.cntr_id')->orderBy('kis_id','desc')
                                                ->where('kitchen_issues.counter_id','=',$counter->cntr_id);
        
                            if($from && $to ){
                                $issues = $issues->whereBetween('date',array($from,$to));
                                $issues = $issues->get();
                            }else{
                                $issues = $issues->where('date',date('Y-m-d'))->get();
                            }
                        
                        
                        
                         foreach($issues as $issue){
                                 $items = KitchenIssueItem::join('kitchen_items','kitchen_issue_items.item_id','=','kitchen_items.ki_id')
                                    ->join('kitchen_issues','kitchen_issue_items.issue_id','=','kitchen_issues.kis_id')
                                    ->join('counters','kitchen_issues.counter_id','=','counters.cntr_id')
                                    ->join('kitchen_purchase_units','kitchen_issue_items.unit_id','=','kitchen_purchase_units.id')
                                    ->where('issue_id','=',$issue->kis_id)
                                    ->select('*','kitchen_issue_items.amount as amount')
                                    ->get();
                                    
                                    
                                     if(count($items) > 0){
                                        $sub_array = ['No:-'.$issue->issue_no.'/'.$counter->counter_name.'/'.date("d-m-Y", strtotime($issue->date)),'','','','',''];
                                        array_push($main_array,$sub_array);
                                        $total  = 0 ;
                                        foreach($items as $item){
                                             $sub_array = ['', $item->item_name, $item->unit,$item->quantity,$item->rate,$item->amount];
                                                        
                                            array_push($main_array,$sub_array);
                                            $total = $total + $item->amount ; 
                                             
                                        }
                                        $sub_array = ['','','','','Total',$total];
                                         array_push($main_array,$sub_array);
                                            
                                    }
                             }
                                
                        }
            
                    }
        
        
        
        
         $counters = Counters::where('purpose','=',2)->get();
                                       
        return view('kitchen_issues.item_wise_report',compact('counters','main_array'));
    }
}
