<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\KitchenPurchase;
use App\Vendors;
use App\KitchenItem;
use App\KitchenPurchaseUnit;
use App\KitchenPurchaseItem; 
use App\KitchenIssue;


class KitchenPurchaseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $purchases =  KitchenPurchase::join('vendors','kitchen_purchases.vendor_id','vendors.v_id');
        if($request->from && $request->to){
            $purchases = ($purchases)->whereBetween('kitchen_purchases.purchase_date',array($request->from,$request->to));
        }else{
            $purchases = ($purchases)->where('kitchen_purchases.purchase_date','=',date('Y-m-d'));
            
        }
        
        if($request->vendor_id){
            $purchases = ($purchases)->where('kitchen_purchases.vendor_id','=',$request->vendor_id);
        }
        $vendors = Vendors::All();
        $purchases = ($purchases)->get();
        return view('kitchen_purchases.index')->with('purchases',$purchases)->with('vendors',$vendors);
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $vendors = Vendors::All();
        $items = KitchenItem::orderby('item_name','ASC')->get();
        $units  =  KitchenPurchaseUnit::all();
        return view('kitchen_purchases.create')->with('vendors',$vendors)
                    ->with('items',$items)
                    ->with('units',$units);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $purchase  =  new KitchenPurchase;
        $purchase->purchase_date = $request->purchase_date;
        $purchase->invoice_no = $request->invoice_no;
        $purchase->vendor_id = $request->vendor_id;
        $purchase->transaction_type = $request->payment_type_id;
        $purchase->gross_amount = $request->gross_amount;
        $purchase->freight = $request->freight;
        $purchase->round_off = $request->round_off;
        $purchase->tax_amount = $request->tax_amount;
        $purchase->net_amount = $request->net_amount;
        $purchase->save();
        
        $pur = KitchenPurchase::latest()->first();
       
        
        if(count($request->items)>0){
            for($i = 0 ; $i < count($request->items) ; $i++){
              $item =  new KitchenPurchaseItem ; 
              $item->item_id  = $request->items[$i];  
              $item->unit_id  = $request->units[$i];
              $item->rate  = $request->rate[$i];
              $item->qty  = $request->qty[$i];
              $item->gross  = $request->gross[$i];
              $item->disc  = $request->disc[$i];
              $item->tax  = $request->tax[$i];
              $item->amount  = $request->amount[$i];
              $item->purchase_id = $pur->kp_id;
              $item->save();
            }
            
        }
        
        
        return redirect()->back()->with('success','Kitchen Purchase Added SuccessFully');
        
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $purchase = KitchenPurchase::join('vendors','kitchen_purchases.vendor_id','vendors.v_id')->find($id);
        $purchase_items = KitchenPurchaseItem::join('kitchen_items','kitchen_purchase_items.item_id','kitchen_items.ki_id')
                        ->join('kitchen_purchase_units','kitchen_purchase_items.unit_id','kitchen_purchase_units.id')
                        ->where('kitchen_purchase_items.purchase_id','=',$id)->get();
        return view('kitchen_purchases.show')->with('purchase',$purchase)->with('items',$purchase_items);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $purchase = KitchenPurchase::join('vendors','kitchen_purchases.vendor_id','vendors.v_id')->find($id);
        $purchase_items = KitchenPurchaseItem::join('kitchen_items','kitchen_purchase_items.item_id','kitchen_items.ki_id')
                        ->join('kitchen_purchase_units','kitchen_purchase_items.unit_id','kitchen_purchase_units.id')
                        ->select('*','kitchen_purchase_items.tax as tax')
                        ->where('purchase_id',$id)->get();
        $vendors = Vendors::All();
        $items = KitchenItem::all();
        $units  =  KitchenPurchaseUnit::all();
        return view('kitchen_purchases.edit')->with('purchase',$purchase)
                                        ->with('vendors',$vendors)
                                        ->with('purchase_items',$purchase_items)
                                        ->with('items',$items)
                                        ->with('units',$units);
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $purchase  = KitchenPurchase::find($id);
        $purchase->purchase_date = $request->purchase_date;
        $purchase->invoice_no = $request->invoice_no;
        $purchase->vendor_id = $request->vendor_id;
        $purchase->transaction_type = $request->payment_type_id;
        $purchase->gross_amount = $request->gross_amount;
        $purchase->freight = $request->freight;
        $purchase->round_off = $request->round_off;
        $purchase->tax_amount = $request->tax_amount;
        $purchase->net_amount = $request->net_amount;
        $purchase->save();
        
        // $pur = KitchenPurchase::latest()->first();
        KitchenPurchaseItem::where('purchase_id','=',$id)->forceDelete();
        
        if(count($request->items)>0){
            for($i = 0 ; $i < count($request->items) ; $i++){
              $item =  new KitchenPurchaseItem ; 
              $item->item_id  = $request->items[$i];  
              $item->unit_id  = $request->units[$i];
              $item->rate  = $request->rate[$i];
              $item->qty  = $request->qty[$i];
              $item->gross  = $request->gross[$i];
              $item->disc  = $request->disc[$i];
              $item->tax  = $request->tax[$i];
              $item->amount  = $request->amount[$i];
              $item->purchase_id = $purchase->kp_id;
              $item->save();
            }
            
        }
        
        
        return redirect("/kitchen_purchases")->with('success','Kitchen Purchase Updated SuccessFully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    
    public function StockReport(Request $request){
        $items = KitchenItem::join('kitchen_purchase_units','kitchen_items.unit_id','=','kitchen_purchase_units.id')->get();
        if($request->from && $request->to){
            $date1 = $request->from ;
            $date2 = $request->to; 
            $yesterday = date('Y-m-d',strtotime($date1."-1 days"));
        }else{
            $date1= date('Y-m-d');
            $date2= date('Y-m-d');
            $yesterday = date('Y-m-d',strtotime("-1 days"));
        }
        $report = [];
        $year = date('Y-04-01');
        if(count($items) > 0){
            foreach($items as $item){
                
                //Purchase 
                $purchases = KitchenPurchase::join('kitchen_purchase_items','kitchen_purchases.kp_id','=','kitchen_purchase_items.purchase_id')
                            ->where('item_id','=',$item->ki_id)
                            ->whereBetween('purchase_date',array($date1,$date2))
                            ->get();
                //Issue 
                $issues = KitchenIssue::join('kitchen_issue_items','kitchen_issues.kis_id','=','kitchen_issue_items.issue_id')
                            ->where('item_id','=',$item->ki_id)
                            ->whereBetween('date',array($date1,$date2))
                            ->get();
                            
                //Purchase Stock    
                $purStock = KitchenPurchase::join('kitchen_purchase_items','kitchen_purchases.kp_id','=','kitchen_purchase_items.purchase_id')
                            ->where('item_id','=',$item->ki_id)
                            ->whereBetween('purchase_date',array($year,$yesterday))
                            ->get();
                            
                //Issue Stock
                $issueStock = KitchenIssue::join('kitchen_issue_items','kitchen_issues.kis_id','=','kitchen_issue_items.issue_id')
                            ->where('item_id','=',$item->ki_id)
                            ->whereBetween('date',array($year,$yesterday))
                            ->get();
                
                $opening = $purStock->sum('qty') - $issueStock->sum('quantity');
                
                $rate = KitchenPurchaseItem::where('item_id','=',$item->ki_id)->latest()->first(); 
                if($rate){
                    
                $op_amount = $opening * $rate->rate;
                }
                $purchase = $purchases->sum('qty');
                $pur_amount = $purchases->sum('amount');
                $issue = $issues->sum('quantity');
                $issue_amount = $issues->sum('amount');
                
                if(count($purchases) > 0 || count($issues) > 0){
                    $report[] = [
                                    'item' => $item->item_name,
                                    'unit' => $item->unit,
                                    'opening' => $opening,
                                    'op_amount' => $op_amount,
                                    'purchase' => $purchase,
                                    'pur_amount' => $pur_amount,
                                    'rcpt' => 0,
                                    'rcpt_amount' => 0,
                                    'issue' => $issue,
                                    'issue_amount' => $issue_amount ,
                                    'cl_stock' => $opening + $purchase - $issue,
                                    'cl_value' => $op_amount + $pur_amount - $issue_amount,
                                ];
                }
            }
        }
        
        return view('kitchen_purchases.stock_report',compact('report'));
    }
    
    
    function unitDetails(Request $request){
        $item = KitchenItem::join('kitchen_purchase_units','kitchen_items.unit_id','=','kitchen_purchase_units.id')->find($request->id);
        $rate = KitchenPurchaseItem::where('item_id','=',$request->id)->latest()->first();
        if($rate){
            $rate = $rate;
        }else{
            $rate = 0;
        }
        return array($item,$rate);
    }
}
