<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Item;
use App\Vendors;
use DB;
use App\Purchases;
use App\PurchaseItems;
use App\Units;
use App\ItemCase;
use App\Stock;

class PurchaseController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $purchases = Purchases::join('payment_methods','purchases.payment_method_id','=','payment_methods.pm_id')
                                ->join('vendors','purchases.vendor_id','=','vendors.v_id')
                                ->orderBy('p_id','desc');
        $vendors = Vendors::all();
        $from  =  $request->from ;
        $to =  $request->to ;
        $vendor  = $request->vendor_id ;

        if($from &&  $to || $vendor  ){
            if($from &&  $to   ){
                $purchases = ($purchases)->whereBetween('purchases.date',[$from, $to]);
            }
            if($vendor ){
                $purchases = ($purchases)->where('purchases.vendor_id','=',$vendor);
            }
            
            $purchases = ($purchases)->get();
        }else{
            $purchases = ($purchases)->where('purchases.date',date('Y-m-d'))->get();
        }
        return view('purchases.index',compact('purchases','vendors'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $items = Item::where('item_head_id','!=','5')->orderBy('name','asc')->get();
        $vendors = Vendors::all();
        $units = Units::all();
        $methods = DB::table('payment_methods')->get();
        $purchase_no = DB::table('purchase_numbers')->first();
        return view('purchases.create',compact('items','vendors','methods','units','purchase_no'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        // return $request->item_id[0];
        $purchase = new Purchases;
        $purchase->purchase_no = $request->purchase_no;
        $purchase->date = $request->date;
        $purchase->payment_method_id = $request->payment_method_id;
        $purchase->vendor_id = $request->vendor_id;
        $purchase->invoice_no = $request->invoice_no;
        $purchase->invoice_date = $request->invoice_date;
        $purchase->total = $request->total;
        $purchase->tcs = $request->tcs;
        $purchase->roundoff = $request->round_off;
        $purchase->discount = $request->discount;
        $purchase->extra = $request->extra;
        $purchase->grand_total = $request->grand_total;
        $purchase->save();
        $purchase_no = DB::table('purchase_numbers')->limit(1)->update(['number' => $request->purchase_no + 1, ]);
        if(count($request->item_id) >0 ){
            for($i = 0 ;$i<count($request->item_id);$i++){
                $item = new PurchaseItems;
                $item->date =  $request->date;
                $item->purchase_id =  $purchase->p_id;
                $item->item_id =  $request->item_id[$i];
                $item->unit =  $request->unit_id[$i];
                $item->measurement =  $request->measurement[$i];
                $item->quantity =  $request->quantity[$i];
                $item->rate =  $request->rate[$i];
                $item->amount =  $request->amount[$i];
                // $item->custom_duty =  $request->custom_duty[$i];
                $item->tax =  $request->tax[$i];
                $item->net_amount =  $request->net_amount[$i];
                $item->save();
                
               $stockCount = Stock::where('item_id',$request->item_id[$i])->where('unit_id',$request->unit_id[$i])->where('counter_id',12)->get();
                
                if($request->measurement[$i] == 0){
                    
                    $case = ItemCase::where('item_id',$request->item_id[$i])->where('unit_id',$request->unit_id[$i])->first();
                    $bottles = $request->quantity[$i] * $case->case_count;
                    
                }else{
                    
                    $bottles = $request->quantity[$i];
                    
                }
               
                $ml = Units::where('u_id',$request->unit_id[$i])->first();
                $total_ml = $bottles * $ml->ml;
                
                if(count($stockCount) == 0){
                    
                    $stocks = new Stock;
                    $stocks->item_id = $request->item_id[$i];
                    $stocks->unit_id = $request->unit_id[$i];
                    $stocks->counter_id = 12;
                    $stocks->bottles = $bottles;
                    $stocks->total_ml = 0;
                    $stocks->pegs = 0;
                    $stocks->priority = $ml->priority;
                    $stocks->save();
                    
                }else{
                    
                    $stock = Stock::where('item_id',$request->item_id[$i])->where('unit_id',$request->unit_id[$i])->where('counter_id',12)->first();
                    
                    $stocks = Stock::where('item_id',$request->item_id[$i])
                                    ->where('unit_id',$request->unit_id[$i])
                                    ->where('counter_id',12)
                                    ->limit(1)->update([
                                        
                                                'bottles' => $stock->bottles + $bottles,
                                                'total_ml' => $stock->total_ml + $total_ml,
                                                'pegs' => 0
                                        
                                        ]);
                    
                }
                
                
                
                
            }
        }
        
        return redirect()->back()->with('success','Purchase added successfully');
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $items = PurchaseItems::join('items','purchase_items.item_id','=','items.item_id')->join('units','purchase_items.unit','=','units.u_id')->where('purchase_id','=',$id)->select('*','purchase_items.amount as pur_amount','purchase_items.tax as pur_tax')->get();
    
        return view('purchases.view_purchase_items',compact('items'));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        $items = Item::where('item_head_id','!=','5')->orderBy('name','asc')->get();
        $vendors = Vendors::all();
        $units = Units::all();
        $methods = DB::table('payment_methods')->get();
        $purchase = Purchases::join('payment_methods','purchases.payment_method_id','=','payment_methods.pm_id')
                                ->join('vendors','purchases.vendor_id','=','vendors.v_id')
                                ->orderBy('p_id','desc')
                                ->find($id);
                                
                                
           
        $purchase_item = PurchaseItems::join('items','purchase_items.item_id','=','items.item_id')->join('units','purchase_items.unit','=','units.u_id')->where('purchase_id','=',$id)
                            ->select('*','purchase_items.amount as pur_amount','purchase_items.tax as pur_tax')->get();
                            
                        
      
        return view('purchases.edit',compact('purchase','purchase_item','items','vendors','methods','units'));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        $purchase = Purchases::find($id);
        $purchase->purchase_no = $request->purchase_no;
        $purchase->date = $request->date;
        $purchase->payment_method_id = $request->payment_method_id;
        $purchase->vendor_id = $request->vendor_id;
        $purchase->invoice_no = $request->invoice_no;
        $purchase->invoice_date = $request->invoice_date;
        $purchase->total = $request->total;
        $purchase->tcs = $request->tcs;
        $purchase->roundoff = $request->round_off;
        $purchase->discount = $request->discount;
        $purchase->extra = $request->extra;
        $purchase->grand_total = $request->grand_total;
        $purchase->save();
        
        
        
        $purchase_item = PurchaseItems::where('purchase_id','=',$id)->get();
        
        foreach($purchase_item as $purch){
            
            $prev_stock = Stock::where('item_id',$purch->item_id)
                                ->where('unit_id',$purch->unit)
                                ->where('counter_id',12)->first();
            
            if($purch->measurement == 0){
                
                $case = ItemCase::where('item_id',$purch->item_id)->where('unit_id',$purch->unit)->first();
                $prev_bottles = $purch->quantity * $case->case_count;
                
            }else{
                
                $prev_bottles = $purch->quantity;
                
            }
            
            $ml = Units::where('u_id',$purch->unit)->first();
            $prev_total_ml = $prev_bottles * $ml->ml;
            
            $stock_update = Stock::where('item_id',$purch->item_id)
                                    ->where('unit_id',$purch->unit)
                                    ->where('counter_id',12)
                                    ->limit(1)->update([
                                        
                                                'bottles' => $prev_stock->bottles - $prev_bottles,
                                                'total_ml' => $prev_stock->total_ml - $prev_total_ml,
                                                // 'pegs' => 0,
                                        
                                        ]);
            
        }
        
        
        
        
        
        $delete = PurchaseItems::where('purchase_id','=',$id)->forceDelete();
      
        if(count($request->item_id) >0 ){
            for($i = 0 ;$i<count($request->item_id);$i++){
                $item = new PurchaseItems;
                $item->date =  $request->date;
                $item->purchase_id =  $purchase->p_id;
                $item->item_id =  $request->item_id[$i];
                $item->unit =  $request->unit_id[$i];
                $item->measurement =  $request->measurement[$i];
                $item->quantity =  $request->quantity[$i];
                $item->rate =  $request->rate[$i];
                $item->amount =  $request->amount[$i];
                $item->tax =  $request->tax[$i];
                $item->net_amount =  $request->net_amount[$i];
                $item->save();
                
                $stockCount = Stock::where('item_id',$request->item_id[$i])->where('unit_id',$request->unit_id[$i])->where('counter_id',12)->get();
                
                if($request->measurement[$i] == 0){
                    
                    $case = ItemCase::where('item_id',$request->item_id[$i])->where('unit_id',$request->unit_id[$i])->first();
                    $bottles = $request->quantity[$i] * $case->case_count;
                    
                }else{
                    
                    $bottles = $request->quantity[$i];
                    
                }
               
                $ml = Units::where('u_id',$request->unit_id[$i])->first();
                $total_ml = $bottles * $ml->ml;
                
                if(count($stockCount) == 0){
                    
                    $stocks = new Stock;
                    $stocks->item_id = $request->item_id[$i];
                    $stocks->unit_id = $request->unit_id[$i];
                    $stocks->counter_id = 12;
                    $stocks->bottles = $bottles;
                    $stocks->total_ml = 0;
                    $stocks->pegs = 0;
                    $stocks->priority = $ml->priority;
                    $stocks->save();
                    
                }else{
                    
                    $stock = Stock::where('item_id',$request->item_id[$i])->where('unit_id',$request->unit_id[$i])->where('counter_id',12)->first();
                    
                    $stocks = Stock::where('item_id',$request->item_id[$i])
                                    ->where('unit_id',$request->unit_id[$i])
                                    ->where('counter_id',12)
                                    ->limit(1)->update([
                                        
                                                'bottles' => $stock->bottles + $bottles,
                                                'total_ml' => $stock->total_ml + $total_ml,
                                                'pegs' => 0
                                        
                                        ]);
                    
                }
            }
        }
        return redirect('/purchases')->with('success','Purchase updated successfully');
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
    
    function taxDetails(Request $request){
        $details = Item::find($request->id);
        return $details;
    }
    
    function caseCountFetch(Request $request){
        $item = Item::find($request->item);
        $case_count  =  ItemCase::where('item_id','=',$item->item_id)->where('unit_id','=',$request->unit)->get();
        if(count($case_count)>0){
             return $case_count[0];
        }else{
             return 0;
        }
       
        
    }
    
    
}
