<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Counters;
use App\BillItems;
use App\Sale;
use App\ItemCase;

class SalePurchaseReportController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        
        $counters = Counters::where('purpose','=','1')->get();
        
        $from = $request->from;
        $to = $request->to;
        $counter = $request->counter_id;
        $date = date('Y-m-d');
        $reports = array();
        
        
        $items = BillItems::join('sales','bill_items.sale_id','=','sales.sale_id')
                            ->join('units','bill_items.unit_id','=','units.u_id')
                            ->join('items','bill_items.item_id','=','items.item_id')
                            ->join('item_categories','items.category_id','=','item_categories.ic_id')
                            ->where('u_id','!=','26')
                            ->where('u_id','!=','27')
                            ->where('u_id','!=','31')
                            ->select('*','bill_items.counter_id as counter_id')
                            ->groupBy('name','u_name');
                            
        
        
        if($from && $to || $counter  ){
            
            if($from && $to){
                
                $items = $items->whereBetween('date',array($from,$to));
                
            }if($counter){
                
                $items = $items->whereIn('bill_items.counter_id',$counter);
                
            }
            $items = $items->get();
            
            $date1 = $from;
            $date2 = $to;
            
        }else{
            
            $items = $items->where('date',$date)->get();
            
            $date1 = $date;
            $date2 = $date;
            
        }
        
        
        
        if(count($items) > 0){
            foreach($items as $item){
                
                                
                $sales = Sale::join('bill_items','sales.sale_id','=','bill_items.sale_id')
                                ->join('units','bill_items.unit_id','=','units.u_id')
                                ->where('item_id','=',$item->item_id)
                                ->where('unit_id','=',$item->u_id)
                                ->whereBetween('sales.date',array($date1,$date2))
                                ->where('sales.counter_id','=',$item->counter_id)
                               ->get();
                               
                               
                $cost = ItemCase::where('item_id','=',$item->item_id)->where('unit_id','=',$item->u_id)->first();
                if( $cost ){
                    
                    $percentage = (($item->rate - $cost->item_amount) / $cost->item_amount) * 100;
                    $item_amount = $cost->item_amount;
                    
                }else{
                    $percentage = 0;
                    $item_amount = 0;
                }
                $percentage = number_format((float)$percentage, 2, '.', '');
                $reports[] = [
                    
                        'category' => $item->category,
                        'item' => $item->name,
                        'total_sale' => $sales->sum('qty'),
                        'unit' => $item->u_name,
                        'cost' => $item_amount,
                        'sale_value' => $item->rate,
                        'percentage' => $percentage,
                    ];
                
            }
        }     
        
        $tmp = array();
 
        foreach($reports as $arg)
        {
            $old_arg =  $arg;
            unset($arg["category"]);
            $tmp[$old_arg['category']][] = $arg;
        }
 
        $output = array();
        foreach($tmp as $type => $labels)
        {
         $output[] = array(
            'category' => $type,
            'items' => $labels
        );
        }
        
         $items =  array();
        
        if(count($output) > 0 ){
            foreach($output as $out){
                $stocks = array();
                $stocks[] = [ $out["category"],"","","","","",""];
                
                 if(count($out["items"]) > 0 ){
                   foreach($out["items"] as $ou){
                       $stocks[] = [
                           "",
                       $ou["item"],
                       $ou["total_sale"],
                       $ou["unit"],
                       $ou["cost"],
                       $ou["sale_value"],
                       $ou["percentage"]
                       ];
                       
                   }
                 }
               
                array_push($items,$stocks);
                
            }
        }
        
        
        
        
        
        return view('reports.sale_purchase_report',compact('counters','items'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        

    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        //
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
