<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Counters;
use App\Item;
use App\Units;
use App\BalancedStock;
use App\Stock;

class StockBalanceController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {   
        if($request->from && $request->to){
            $from = $request->from;
            $to = $request->to;
        }else{
            $from = date('Y-m-d');
            $to = date('Y-m-d');
        }
        $stocks = BalancedStock::join('counters','balanced_stocks.counter_id','=','counters.cntr_id')
                                ->join('items','balanced_stocks.item_id','=','items.item_id')
                                ->join('units','balanced_stocks.unit_id','=','units.u_id')
                                ->whereBetween('date',array($from,$to))
                                ->orderBy('bs_id','desc')
                                ->get();
        return view('stock_balance.index',compact('stocks'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        $counters = Counters::where('purpose','=','1')->get();
        $units = Units::where('u_id','!=','26')->where('u_id','!=','31')->get();
        $items = Item::where('item_head_id','!=','5')->get();
        
        return view('stock_balance.create',compact('counters','units','items'));
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        
        $stock = new BalancedStock;
        $stock->date = $request->date;
        $stock->item_id = $request->item_id;
        $stock->counter_id = $request->counter_id;
        $stock->unit_id = $request->unit_id;
        $stock->bottles = $request->bottles;
        $stock->pegs = $request->pegs;
        $stock->remarks = $request->remarks;
        $stock->save();
        
        $initial_stock = Stock::where('counter_id',$request->counter_id)
                    ->where('item_id',$request->item_id)
                    ->where('unit_id',$request->unit_id)
                    ->first();
        
        $update_stock = Stock::where('counter_id',$request->counter_id)
                    ->where('item_id',$request->item_id)
                    ->where('unit_id',$request->unit_id)
                    ->limit(1)->update([
                            
                            'bottles' => $initial_stock->bottles - $stock->bottles,
                            'pegs' => $initial_stock->pegs - $stock->pegs,
                            
                        ]);
        
        return redirect('stock_balance')->with('success','Stock balance Added Successfully');
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
