<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Counters;
use App\Stock;
use App\VerifiedStock;

class VerifyStockController extends Controller
{
    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index(Request $request)
    {
        $counters = Counters::where('purpose','=','1')->get();
        
        
        
        
        if($request->date ){
            $today = $request->date;
        }else{
            $today = date('Y-m-d');
        }
        
        $from = $today;
        $to = $today;
        
        if($request->counter_id){
            $stocks = VerifiedStock::join('items','verified_stocks.item_id','=','items.item_id')
                                ->join('units','verified_stocks.unit_id','=','units.u_id')
                                ->join('item_heads','items.item_head_id','=','item_heads.ih_id')
                                ->where('verified_stocks.counter_id',$request->counter_id)
                                ->whereBetween('date',array($from,$to))
                                ->get();
        }else{
            $stocks = VerifiedStock::join('items','verified_stocks.item_id','=','items.item_id')
                                ->join('units','verified_stocks.unit_id','=','units.u_id')
                                ->join('item_heads','items.item_head_id','=','item_heads.ih_id')
                                ->whereBetween('date',array($from,$to))
                                ->get();
        }
        
        
        
        $tmp = array();
 
        foreach($stocks as $arg)
        {
            $old_arg =  $arg;
            
            // unset($arg->ih_name);
           
            $tmp[$old_arg->ih_name][] = $arg;
        }
        
 
        $output = array();
 
        foreach($tmp as $type => $labels)
        {
             $output[] = array(
                'head' => $type,
                'items' => $labels
            );
        }
        
        
        
        $last_array =  array();
        
        if(count($output) > 0 ){
            foreach($output as $out){
                $stock_array = array();
                $stock_array[] = [ $out["head"],"","","",""];
                
                 if(count($out["items"]) > 0 ){
                   foreach($out["items"] as $ou){
                       $stock_array[] = [ "",$ou->name,$ou->u_name,$ou->bottles,$ou->pegs];
                   }
                 }
                $stock_array[] =["","","","",""];
                array_push($last_array,$stock_array);
                
            }
        }
        
        return view('stock_verification.index',compact('last_array','counters'));
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create(Request $request)
    {
        
        $counters = Counters::where('purpose','=','1')->get();
        
        $date = date('Y-m-d');
        
        if($request->counter_id){
            
            $verified = VerifiedStock::where('counter_id',$request->counter_id)->where('date',$date)->get();
            
            if(count($verified) > 0){
                foreach($verified as $verify){
                    
                    return redirect('/verify_stock/create')->with('danger','Stock already verified');
                            
                
                }
            }
            else{
                
                $stocks = Stock::join('items','stocks.item_id','=','items.item_id')
                                ->join('units','stocks.unit_id','=','units.u_id')
                                ->join('item_heads','items.item_head_id','=','item_heads.ih_id')
                                ->where('stocks.counter_id',$request->counter_id)
                                ->where(function($q) {
                                     $q->where('pegs',"!=", '0')
                                       ->orWhere('bottles',"!=", '0');
                                 })
                                ->get();
            }
        }
        else{
            $stocks = [];
        }
        
        
        
        $tmp = array();
 
        foreach($stocks as $arg)
        {
            $old_arg =  $arg;
            
            // unset($arg->ih_name);
           
            $tmp[$old_arg->ih_name][] = $arg;
        }
        
 
        $output = array();
 
        foreach($tmp as $type => $labels)
        {
             $output[] = array(
                'head' => $type,
                'items' => $labels
            );
        }
        
        
        
        $last_array =  array();
        
        if(count($output) > 0 ){
            foreach($output as $out){
                $stock_array = array();
                $stock_array[] = [ $out["head"],"","","",""];
                
                 if(count($out["items"]) > 0 ){
                   foreach($out["items"] as $ou){
                       $stock_array[] = [ "",$ou->name,$ou->u_name,$ou->bottles,$ou->pegs];
                   }
                 }
                $stock_array[] =["","","","","","",""];
                array_push($last_array,$stock_array);
                
            }
        }
        
        
        $counter_id = $request->counter_id;
        
        return view('stock_verification.create',compact('counters','last_array','counter_id'));
        
        
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $stocks = Stock::where('stocks.counter_id',$request->counter_id)->get();
        
        foreach($stocks as $stock){
            $verified = new VerifiedStock;
            $verified->date = date('Y-m-d');
            $verified->item_id = $stock->item_id;
            $verified->unit_id = $stock->unit_id;
            $verified->counter_id = $request->counter_id;
            $verified->bottles = $stock->bottles;
            $verified->pegs = $stock->pegs;
            $verified->priority = $stock->priority;
            $verified->save();
        }
        
        
        return Redirect('/verify_stock/create')->with('success','Stock Verified');
        
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        //
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        //
    }
}
